@@ -1,4 +1,5 @@
 """commonly used navigation paths"""
+
 from typing import Any, Dict, List, Literal, Optional, overload
 
 CONTENT = ["contents", 0]
@@ -95,12 +96,11 @@ def nav(root: Dict, items: List[Any], none_if_absent: bool = False) -> Optional[
     try:
         for k in items:
             root = root[k]
-        return root
-    except Exception as err:
+    except (KeyError, IndexError, TypeError) as e:
         if none_if_absent:
             return None
-        else:
-            raise err
+        raise type(e)(f"Unable to find '{k}' using path {items!r} on {root!r}, exception: {e}")
+    return root
 
 
 def find_object_by_key(object_list, key, nested=None, is_key=False):
