@@ -44,15 +44,13 @@ def parse_playlist_items(results, menu_entries: Optional[List[List]] = None, is_
         if title == "Song deleted":
             continue
 
+        flex_column_count = len(data["flexColumns"])
+
         artists = parse_song_artists(data, 1)
 
-        album = parse_song_album(data, 2)
+        album = parse_song_album(data, flex_column_count - 1) if not is_album else None
 
-        views = None
-        if album and album["id"] is None:
-            # views currently only present on albums and formatting is localization-dependent -> no parsing
-            if (views := (get_item_text(data, 2))) is not None:
-                album = None
+        views = get_item_text(data, 2) if flex_column_count == 4 or is_album else None
 
         duration = None
         if "fixedColumns" in data:
